@@ -27,7 +27,7 @@ import signal
 import sys
 
 # Global name
-__version__ = '2.8.2'
+__version__ = '2.8.7'
 __author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
 __license__ = 'LGPLv3'
 
@@ -70,11 +70,11 @@ def __signal_handler(signal, frame):
 
 def end():
     """Stop Glances."""
-    if core.is_standalone():
+    if core.is_standalone() and not WINDOWS:
         # Stop the standalone (CLI)
         standalone.end()
         logger.info("Stop Glances (with CTRL-C)")
-    elif core.is_client():
+    elif core.is_client() and not WINDOWS:
         # Stop the client
         client.end()
         logger.info("Stop Glances client (with CTRL-C)")
@@ -230,9 +230,6 @@ def main():
             start_client(config=config, args=args)
     elif core.is_server():
         start_server(config=config, args=args)
-    elif core.is_webserver() or (core.is_standalone() and WINDOWS):
+    elif core.is_webserver():
         # Web server mode replace the standalone mode on Windows OS
-        # In this case, try to start the web browser mode automaticaly
-        if core.is_standalone() and WINDOWS:
-            args.open_web_browser = True
         start_webserver(config=config, args=args)
