@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,7 @@
 import sys
 from numbers import Number
 
-from glances.compat import NoOptionError, NoSectionError, range
+from glances.compat import range
 from glances.logger import logger
 from glances.exports.glances_export import GlancesExport
 
@@ -37,11 +37,16 @@ class Export(GlancesExport):
         """Init the Statsd export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Load the InfluxDB configuration file
-        self.host = None
-        self.port = None
+        # Mandatories configuration keys (additional to host and port)
+        # N/A
+
+        # Optionals configuration keys
         self.prefix = None
-        self.export_enable = self.load_conf()
+
+        # Load the InfluxDB configuration file
+        self.export_enable = self.load_conf('statsd',
+                                            mandatories=['host', 'port'],
+                                            options=['prefix'])
         if not self.export_enable:
             sys.exit(2)
 
@@ -50,38 +55,14 @@ class Export(GlancesExport):
             self.prefix = 'glances'
 
         # Init the Statsd client
-        self.client = StatsClient(self.host,
-                                  int(self.port),
-                                  prefix=self.prefix)
-
-    def load_conf(self, section="statsd"):
-        """Load the Statsd configuration in the Glances configuration file."""
-        if self.config is None:
-            return False
-        try:
-            self.host = self.config.get_value(section, 'host')
-            self.port = self.config.get_value(section, 'port')
-        except NoSectionError:
-            logger.critical("No Statsd configuration found")
-            return False
-        except NoOptionError as e:
-            logger.critical("Error in the Statsd configuration (%s)" % e)
-            return False
-        else:
-            logger.debug("Load Statsd from the Glances configuration file")
-        # Prefix is optional
-        try:
-            self.prefix = self.config.get_value(section, 'prefix')
-        except NoOptionError:
-            pass
-        return True
+        self.client = self.init()
 
     def init(self, prefix='glances'):
         """Init the connection to the Statsd server."""
         if not self.export_enable:
             return None
         return StatsClient(self.host,
-                           self.port,
+                           int(self.port),
                            prefix=prefix)
 
     def export(self, name, columns, points):
@@ -89,10 +70,10 @@ class Export(GlancesExport):
         for i in range(len(columns)):
             if not isinstance(points[i], Number):
                 continue
-            stat_name = '{0}.{1}'.format(name, columns[i])
+            stat_name = '{}.{}'.format(name, columns[i])
             stat_value = points[i]
             try:
                 self.client.gauge(stat_name, stat_value)
             except Exception as e:
                 logger.error("Can not export stats to Statsd (%s)" % e)
-        logger.debug("Export {0} stats to Statsd".format(name))
+        logger.debug("Export {} stats to Statsd".format(name))
